@@ -17,6 +17,14 @@ class DetectController:
             return res.text
         raise Exception(res.text)
 
+    @verify_credentials
+    def delete_endpoint(self, ident: str):
+        """ Delete an endpoint from your account """
+        params = dict(id=ident)
+        res = requests.delete(f'{self.account.hq}/detect/endpoint', headers=self.account.headers, json=params)
+        if res.status_code != 200:
+            raise Exception(res.text)
+
     @verify_credentials
     def describe_activity(self, days=7):
         """ Get report for an Account """
@@ -59,3 +67,21 @@ class DetectController:
         res = requests.delete(f'{self.account.hq}/detect/queue/{ident}', headers=self.account.headers)
         if res.status_code != 200:
             raise Exception(res.text)
+
+    @verify_credentials
+    def stats(self, ident: str, days: int = 30):
+        """ Pull social statistics for a specific test """
+        params = dict(days=days)
+        res = requests.get(f'{self.account.hq}/detect/{ident}/social', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
+
+    @verify_credentials
+    def observe(self, row_id, value):
+        """ Mark a result as observed """
+        params = dict(row_id=row_id, value=value)
+        res = requests.post(f'{self.account.hq}/detect/observe', headers=self.account.headers, json=params)
+        if res.status_code == 200:
+            return res.text
+        raise Exception(res.text)
