@@ -32,19 +32,19 @@ class Permission(Enum):
     def _missing_(cls, value):
         return Permission.UNKNOWN
 
-
+@unique
 class Lookup(Enum):
-    Error = 1
-    Passed = 100
-    Failed = 101
-    Timeout = 102
-    CleanupError = 103
-    NotRelevant = 104
-    Quarantined_1 = 105
-    Incompatible = 126
-    Quarantined_2 = 127
-    Unexpected = 256
+    ERROR = 1
+    PASSED = 100
+    FAILED = 101
+    TIMEOUT = 102
+    CLEANUP_ERROR = 103
+    NOT_RELEVANT = 104
+    QUARANTINED = 105
+    INCOMPATIBLE = 126
+    QUARANTINED_VST = 127
+    UNEXPECTED = 256
 
     @classmethod
     def _missing_(cls, value):
-        return Lookup.Unexpected
+        return Lookup.UNEXPECTED
